@@ -16,3 +16,11 @@ test_that("cXline3", {
 test_that("cXline4", {
     check_ui_test(cXline4())
 })
+
+test_that("cXline5", {
+    check_ui_test(cXline5())
+})
+
+test_that("cXline6", {
+    check_ui_test(cXline6())
+})
